about summary refs log tree commit diff
path: root/editor/pgmdeshadow.c
diff options
context:
space:
mode:
Diffstat (limited to 'editor/pgmdeshadow.c')
-rw-r--r--editor/pgmdeshadow.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/editor/pgmdeshadow.c b/editor/pgmdeshadow.c
index 948c6cba..2c3a90f8 100644
--- a/editor/pgmdeshadow.c
+++ b/editor/pgmdeshadow.c
@@ -21,7 +21,7 @@
 */
 
 /*
- * Algorithm reference: Luc Vincent, "Morphological Grayscale Reruction
+ * Algorithm reference: Luc Vincent, "Morphological Grayscale Reconstruction
  * in Image Analysis: Applications and Efficient Algorithms," IEEE
  * Transactions on Image Processing, vol. 2, no. 2, April 1993, pp. 176-201.
  *
@@ -75,7 +75,7 @@ parseCommandLine(int argc, char ** argv,
    was passed to us as the argv array.
 -----------------------------------------------------------------------------*/
     optEntry * option_def;
         /* Instructions to optParseOptions3 on how to parse our options.
          */
     optStruct3 opt;
 
@@ -91,7 +91,7 @@ parseCommandLine(int argc, char ** argv,
     opt.short_allowed = FALSE;  /* We have no short (old-fashioned) options */
     opt.allowNegNum = FALSE;  /* We may have parms that are negative numbers */
 
-    optParseOptions3(&argc, argv, opt, sizeof(opt), 0);
+    pm_optParseOptions3(&argc, argv, opt, sizeof(opt), 0);
         /* Uses and sets argc, argv, and some of *cmdlineP and others. */
 
     if (argc-1 < 1)
@@ -75,7 +75,7 @@ parseCommandLine(int argc, char ** argv,
 -----------------------------------------------------------------------------*/
     optEntry * option_def;
-        /* Instructions to optParseOptions3 on how to parse our options.
+        /* Instructions to pm_optParseOptions3 on how to parse our options.
          */
     optStruct3 opt;